==> nomachine-8.6.1-1-x86_64.pkg.tar.zst: NX/lib/perl/nxserver/Common/NXTime.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2023 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXNODE, NX protocol compression and NX extensions to this software      #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
sub Common::NXTime::getSecondsSinceEpoch{package Common::NXTime;no warnings;(my $seconds
=libnxh::NXGetTime ());return ($seconds);}sub 
Common::NXTime::getSecondsAndMicrosecondsSinceEpoch{package Common::NXTime;no 
warnings;(my $buffer=("\x3a" x (0x0a38+ 319-0x0b4f)));my (@arr);my (@result);(my $retval
=libnxh::NXSecondsAndMicrosecondsSinceEpoch ($buffer));if (($retval!=(-
(0x04f2+ 4038-0x14b7)))){(@arr=split ( /:/ ,$buffer,(0x0489+ 7054-0x2017)));(
@result=splice (@arr,(0x0ba5+ 6082-0x2367),(0x036f+ 8978-0x267f)));return (
@result);}else{(my $errorNumber=libnxh::NXGetError ());(my $errorString=
libnxh::NXGetErrorString ());syswrite (STDERR,
"\x4e\x58\x3e\x20\x35\x39\x36\x20\x45\x72\x72\x6f\x72\x3a\x20\x43\x61\x6e\x6e\x6f\x74\x20\x67\x65\x74\x20\x63\x75\x72\x72\x65\x6e\x74\x20\x74\x69\x6d\x65\x20\x77\x69\x74\x68\x20\x6d\x69\x63\x72\x6f\x73\x65\x63\x6f\x6e\x64\x20\x70\x72\x65\x63\x69\x73\x69\x6f\x6e\x2e\x0a"
);syswrite (STDERR,((((
"\x4e\x58\x3e\x20\x35\x39\x36\x20\x45\x72\x72\x6f\x72\x3a\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20"
.$errorNumber)."\x2c\x20\x27").$errorString)."\x27\x2e\x0a"));main::nxexit ();}}
sub Common::NXTime::getMillisecondsSinceEpoch{package Common::NXTime;no warnings
;(my ($seconds,$microseconds)=getSecondsAndMicrosecondsSinceEpoch ());(my $milliseconds
=int ((($seconds *(0x1193+ 3001-0x1964))+($microseconds/(0x0f64+ 3954-0x1aee))))
);return ($milliseconds);}sub Common::NXTime::getLocalTime{package 
Common::NXTime;no warnings;my (@arr);my (@result);(my $buffer=("\x3a" x 
(0x13c5+ 4245-0x2432)));(my $retval=libnxh::NXLocalTime ($buffer));if (($retval
!=(-(0x007c+ 7133-0x1c58)))){(@arr=split ( /:/ ,$buffer,(0x11f4+ 732-0x14d0)));(
@result=splice (@arr,(0x01ff+ 851-0x0552),(0x18bf+ 314-0x19f0)));return (@result
);}else{(my $errorNumber=libnxh::NXGetError ());(my $errorString=
libnxh::NXGetErrorString ());syswrite (STDERR,
"\x4e\x58\x3e\x20\x35\x39\x36\x20\x45\x72\x72\x6f\x72\x3a\x20\x43\x61\x6e\x6e\x6f\x74\x20\x67\x65\x74\x20\x63\x75\x72\x72\x65\x6e\x74\x20\x74\x69\x6d\x65\x2e\x0a"
);syswrite (STDERR,((((
"\x4e\x58\x3e\x20\x35\x39\x36\x20\x45\x72\x72\x6f\x72\x3a\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20"
.$errorNumber)."\x2c\x20\x27").$errorString)."\x27\x2e\x0a"));main::nxexit ();}}
sub Common::NXTime::getLocalTimeFromTimestamp{package Common::NXTime;no warnings
;(my $stamp=shift (@_));my (@arr);my (@result);(my $buffer=("\x3a" x 
(0x00b0+ 3493-0x0e2d)));(my $retval=libnxh::NXLocalTimeFromTimestamp ($stamp,
$buffer));if (($retval!=(-(0x08b3+ 4717-0x1b1f)))){(@arr=split ( /:/ ,$buffer,
(0x076b+ 7231-0x23aa)));(@result=splice (@arr,(0x1fe0+  62-0x201e),
(0x05ca+ 8378-0x267b)));return (@result);}else{(my $errorNumber=
libnxh::NXGetError ());(my $errorString=libnxh::NXGetErrorString ());syswrite (
STDERR,((
"\x4e\x58\x3e\x20\x35\x39\x36\x20\x45\x72\x72\x6f\x72\x3a\x20\x43\x61\x6e\x6e\x6f\x74\x20\x67\x65\x74\x20\x63\x75\x72\x72\x65\x6e\x74\x20\x74\x69\x6d\x65\x2e\x20\x41\x72\x67\x75\x6d\x65\x6e\x74\x20\x69\x73\x20"
.$stamp)."\x2e\x0a"));syswrite (STDERR,((((
"\x4e\x58\x3e\x20\x35\x39\x36\x20\x45\x72\x72\x6f\x72\x3a\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20"
.$errorNumber)."\x2c\x20\x27").$errorString)."\x27\x2e\x0a"));main::nxexit ();}}
sub Common::NXTime::getDateString{package Common::NXTime;no warnings;(my $string
=libnxh::NXLocalTimeAsString ());return ($string);}sub 
Common::NXTime::getTimestamp{package Common::NXTime;no warnings;(my ($sec,
$microsec)=getSecondsAndMicrosecondsSinceEpoch ());(my (@time)=
getLocalTimeFromTimestamp ($sec));(my $milisec=sprintf ("\x25\x30\x36\x64",
$microsec));($milisec=((substr ($milisec,(0x0b9d+  39-0x0bc4),
(0x0381+ 4467-0x14f1))."\x2e").substr ($milisec,(0x0a41+ 4300-0x1b0a))));(my $Timestamp
=((((((sprintf ("\x25\x30\x32\x64",$time[(0x1498+ 1841-0x1bc7)])."\x3a").sprintf
 ("\x25\x30\x32\x64",$time[(0x0473+ 1564-0x0a8e)]))."\x3a").sprintf (
"\x25\x30\x32\x64",$time[(0x0e5d+ 5793-0x24fe)]))."\x3a").sprintf ($milisec)));
return ($Timestamp);}sub Common::NXTime::getTimestampOnlyMicroseconds{package 
Common::NXTime;no warnings;(my ($sec,$microsec)=
getSecondsAndMicrosecondsSinceEpoch ());(my $milisec=sprintf ("\x25\x30\x36\x64"
,$microsec));($milisec=((substr ($milisec,(0x1458+ 249-0x1551),
(0x23ac+ 724-0x267d))."\x2e").substr ($milisec,(0x0590+ 890-0x0907))));(my $Timestamp
=sprintf ($milisec));return ($Timestamp);}sub Common::NXTime::__getTimeMs{
package Common::NXTime;no warnings;(my ($sec,$microsec)=
getSecondsAndMicrosecondsSinceEpoch ());(my (@time)=getLocalTimeFromTimestamp (
$sec));(my $milisec=sprintf ("\x25\x30\x36\x64",$microsec));($milisec=(substr (
$milisec,(0x062d+ 6130-0x1e1f),(0x0106+ 4643-0x1326)).substr ($milisec,
(0x0d01+ 1755-0x13d9))));return ($milisec,@time);}sub Common::NXTime::getTimeMs{
package Common::NXTime;no warnings;(my ($milisec,@time)=__getTimeMs ());(my $TimeMs
=((((sprintf ("\x25\x30\x32\x64",$time[(0x0479+ 1776-0x0b67)]).sprintf (
"\x25\x30\x32\x64",$time[(0x0e36+ 3957-0x1daa)])).sprintf ("\x25\x30\x32\x64",
$time[(0x0381+ 2624-0x0dc1)]))."\x2e").sprintf ($milisec)));return ($TimeMs);}
sub Common::NXTime::getLoggerTimeline{package Common::NXTime;no warnings;(my (
$milisec,@time)=__getTimeMs ());($milisec=((substr ($milisec,
(0x0813+ 4796-0x1acf),(0x1cd2+ 2386-0x2621))."\x2e").substr ($milisec,
(0x1046+ 2630-0x1a89))));(my $Timeline=(sprintf (
"\x25\x30\x34\x64\x2d\x25\x30\x32\x64\x2d\x25\x30\x32\x64\x20\x25\x30\x32\x64\x3a\x25\x30\x32\x64\x3a\x25\x30\x32\x64\x20"
,((0x0da1+ 733-0x0912)+$time[(0x100d+ 420-0x11ac)]),((0x1471+ 2763-0x1f3b)+$time
[(0x0fac+ 5040-0x2358)]),$time[(0x0bf8+ 3202-0x1877)],$time[
(0x0280+ 8468-0x2392)],$time[(0x008f+ 6964-0x1bc2)],$time[(0x0bd0+ 6910-0x26ce)]
).$milisec));return ($Timeline);}sub 
Common::NXTime::getLoggerTimelineOnlyMicroseconds{package Common::NXTime;no 
warnings;(my ($milisec,@time)=__getTimeMs ());($milisec=((substr ($milisec,
(0x1189+ 1974-0x193f),(0x1f5a+ 1033-0x2360))."\x2e").substr ($milisec,
(0x1892+ 1345-0x1dd0))));(my $Timeline=sprintf ($milisec));return ($Timeline);}
sub Common::NXTime::convertLocalTimeFromTimestampToHumanReadableString{package 
Common::NXTime;no warnings;(my $timestamp=shift (@_));(my (@time)=
getLocalTimeFromTimestamp ($timestamp));(my $timeString=sprintf (
"\x25\x30\x34\x64\x2d\x25\x30\x32\x64\x2d\x25\x30\x32\x64\x20\x25\x30\x32\x64\x3a\x25\x30\x32\x64\x3a\x25\x30\x32\x64"
,((0x09df+ 1467-0x082e)+$time[(0x1b64+ 887-0x1ed6)]),($time[(0x1d43+ 704-0x1fff)
]+(0x1b80+ 2373-0x24c4)),$time[(0x0d6c+ 571-0x0fa4)],$time[(0x0802+ 6687-0x221f)
],$time[(0x0d47+ 4366-0x1e54)],$time[(0x0ab0+ 2035-0x12a3)]));return (
$timeString);}sub Common::NXTime::getDateTimeForFileName{package Common::NXTime;
no warnings;(my $dateTime=getLoggerTimeline ());($dateTime=~ s/ [^ ]*$// );(
$dateTime=~ s/-/./gm );($dateTime=~ s/:/./gm );($dateTime=~ s/ /-/gm );return (
$dateTime);}sub Common::NXTime::getSecondsInWeek{package Common::NXTime;no 
warnings;return (604800);}sub Common::NXTime::convertSecondsToDaysRounded{
package Common::NXTime;no warnings;(my $seconds=shift (@_));(my $days=($seconds/
86400));($days=(int ($days)+(0x0969+ 4789-0x1c1d)));return ($days);}package 
Common::NXTime;no warnings;"\x3f\x3f\x3f";

==> nomachine-8.9.1-1-x86_64.pkg.tar.zst: NX/lib/perl/nxserver/Common/NXTime.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2023 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXNODE, NX protocol compression and NX extensions to this software      #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
sub Common::NXTime::getSecondsSinceEpoch{package Common::NXTime;no warnings;(my $seconds
=libnxh::NXGetTime ());return ($seconds);}sub 
Common::NXTime::getSecondsAndMicrosecondsSinceEpoch{package Common::NXTime;no 
warnings;(my $buffer=("\x3a" x (0x1059+ 2082-0x1853)));my (@arr);my (@result);(my $retval
=libnxh::NXSecondsAndMicrosecondsSinceEpoch ($buffer));if (($retval!=(-
(0x08fb+ 5424-0x1e2a)))){(@arr=split ( /:/ ,$buffer,(0x1bad+ 1830-0x22d3)));(
@result=splice (@arr,(0x07c0+ 4740-0x1a44),(0x011d+ 6731-0x1b66)));return (
@result);}else{(my $errorNumber=libnxh::NXGetError ());(my $errorString=
libnxh::NXGetErrorString ());syswrite (STDERR,
"\x4e\x58\x3e\x20\x35\x39\x36\x20\x45\x72\x72\x6f\x72\x3a\x20\x43\x61\x6e\x6e\x6f\x74\x20\x67\x65\x74\x20\x63\x75\x72\x72\x65\x6e\x74\x20\x74\x69\x6d\x65\x20\x77\x69\x74\x68\x20\x6d\x69\x63\x72\x6f\x73\x65\x63\x6f\x6e\x64\x20\x70\x72\x65\x63\x69\x73\x69\x6f\x6e\x2e\x0a"
);syswrite (STDERR,((((
"\x4e\x58\x3e\x20\x35\x39\x36\x20\x45\x72\x72\x6f\x72\x3a\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20"
.$errorNumber)."\x2c\x20\x27").$errorString)."\x27\x2e\x0a"));main::nxexit ();}}
sub Common::NXTime::getMillisecondsSinceEpoch{package Common::NXTime;no warnings
;(my ($seconds,$microseconds)=getSecondsAndMicrosecondsSinceEpoch ());(my $milliseconds
=int ((($seconds *(0x0738+ 4400-0x1480))+($microseconds/(0x07c9+ 3037-0x0fbe))))
);return ($milliseconds);}sub Common::NXTime::getLocalTime{package 
Common::NXTime;no warnings;my (@arr);my (@result);(my $buffer=("\x3a" x 
(0x09e0+ 6550-0x234e)));(my $retval=libnxh::NXLocalTime ($buffer));if (($retval
!=(-(0x1df0+ 245-0x1ee4)))){(@arr=split ( /:/ ,$buffer,(0x11a9+ 1171-0x163c)));(
@result=splice (@arr,(0x0051+ 4991-0x13d0),(0x03fc+ 4612-0x15f7)));return (
@result);}else{(my $errorNumber=libnxh::NXGetError ());(my $errorString=
libnxh::NXGetErrorString ());syswrite (STDERR,
"\x4e\x58\x3e\x20\x35\x39\x36\x20\x45\x72\x72\x6f\x72\x3a\x20\x43\x61\x6e\x6e\x6f\x74\x20\x67\x65\x74\x20\x63\x75\x72\x72\x65\x6e\x74\x20\x74\x69\x6d\x65\x2e\x0a"
);syswrite (STDERR,((((
"\x4e\x58\x3e\x20\x35\x39\x36\x20\x45\x72\x72\x6f\x72\x3a\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20"
.$errorNumber)."\x2c\x20\x27").$errorString)."\x27\x2e\x0a"));main::nxexit ();}}
sub Common::NXTime::getLocalTimeFromTimestamp{package Common::NXTime;no warnings
;(my $stamp=shift (@_));my (@arr);my (@result);(my $buffer=("\x3a" x 
(0x00e3+ 482-0x029d)));(my $retval=libnxh::NXLocalTimeFromTimestamp ($stamp,
$buffer));if (($retval!=(-(0x1e44+ 1939-0x25d6)))){(@arr=split ( /:/ ,$buffer,
(0x1092+ 4993-0x2413)));(@result=splice (@arr,(0x0447+ 7934-0x2345),
(0x0809+ 2205-0x109d)));return (@result);}else{(my $errorNumber=
libnxh::NXGetError ());(my $errorString=libnxh::NXGetErrorString ());syswrite (
STDERR,((
"\x4e\x58\x3e\x20\x35\x39\x36\x20\x45\x72\x72\x6f\x72\x3a\x20\x43\x61\x6e\x6e\x6f\x74\x20\x67\x65\x74\x20\x63\x75\x72\x72\x65\x6e\x74\x20\x74\x69\x6d\x65\x2e\x20\x41\x72\x67\x75\x6d\x65\x6e\x74\x20\x69\x73\x20"
.$stamp)."\x2e\x0a"));syswrite (STDERR,((((
"\x4e\x58\x3e\x20\x35\x39\x36\x20\x45\x72\x72\x6f\x72\x3a\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20"
.$errorNumber)."\x2c\x20\x27").$errorString)."\x27\x2e\x0a"));main::nxexit ();}}
sub Common::NXTime::getDateString{package Common::NXTime;no warnings;(my $string
=libnxh::NXLocalTimeAsString ());return ($string);}sub 
Common::NXTime::getTimestamp{package Common::NXTime;no warnings;(my ($sec,
$microsec)=getSecondsAndMicrosecondsSinceEpoch ());(my (@time)=
getLocalTimeFromTimestamp ($sec));(my $milisec=sprintf ("\x25\x30\x36\x64",
$microsec));($milisec=((substr ($milisec,(0x0f34+ 3919-0x1e83),
(0x09aa+ 5915-0x20c2))."\x2e").substr ($milisec,(0x11d8+ 2485-0x1b8a))));(my $Timestamp
=((((((sprintf ("\x25\x30\x32\x64",$time[(0x1437+ 2329-0x1d4e)])."\x3a").sprintf
 ("\x25\x30\x32\x64",$time[(0x161f+ 339-0x1771)]))."\x3a").sprintf (
"\x25\x30\x32\x64",$time[(0x09a1+ 4648-0x1bc9)]))."\x3a").sprintf ($milisec)));
return ($Timestamp);}sub Common::NXTime::getTimestampOnlyMicroseconds{package 
Common::NXTime;no warnings;(my ($sec,$microsec)=
getSecondsAndMicrosecondsSinceEpoch ());(my $milisec=sprintf ("\x25\x30\x36\x64"
,$microsec));($milisec=((substr ($milisec,(0x0794+ 6074-0x1f4e),
(0x15c0+ 3247-0x226c))."\x2e").substr ($milisec,(0x03a9+ 2134-0x0bfc))));(my $Timestamp
=sprintf ($milisec));return ($Timestamp);}sub Common::NXTime::__getTimeMs{
package Common::NXTime;no warnings;(my ($sec,$microsec)=
getSecondsAndMicrosecondsSinceEpoch ());(my (@time)=getLocalTimeFromTimestamp (
$sec));(my $milisec=sprintf ("\x25\x30\x36\x64",$microsec));($milisec=(substr (
$milisec,(0x1b79+ 192-0x1c39),(0x0449+ 2054-0x0c4c)).substr ($milisec,
(0x0365+ 2417-0x0cd3))));return ($milisec,@time);}sub Common::NXTime::getTimeMs{
package Common::NXTime;no warnings;(my ($milisec,@time)=__getTimeMs ());(my $TimeMs
=((((sprintf ("\x25\x30\x32\x64",$time[(0x0103+ 638-0x037f)]).sprintf (
"\x25\x30\x32\x64",$time[(0x1283+   7-0x1289)])).sprintf ("\x25\x30\x32\x64",
$time[(0x0b54+ 3389-0x1891)]))."\x2e").sprintf ($milisec)));return ($TimeMs);}
sub Common::NXTime::getLoggerTimeline{package Common::NXTime;no warnings;(my (
$milisec,@time)=__getTimeMs ());($milisec=((substr ($milisec,
(0x13b0+ 3164-0x200c),(0x1254+ 2749-0x1d0e))."\x2e").substr ($milisec,
(0x06b4+ 6170-0x1ecb))));(my $Timeline=(sprintf (
"\x25\x30\x34\x64\x2d\x25\x30\x32\x64\x2d\x25\x30\x32\x64\x20\x25\x30\x32\x64\x3a\x25\x30\x32\x64\x3a\x25\x30\x32\x64\x20"
,((0x0ceb+ 4655-0x17ae)+$time[(0x252a+ 150-0x25bb)]),((0x0b54+ 1619-0x11a6)+
$time[(0x0441+ 460-0x0609)]),$time[(0x1508+ 1858-0x1c47)],$time[
(0x1451+ 1522-0x1a41)],$time[(0x0791+ 4684-0x19dc)],$time[(0x02f9+ 4278-0x13af)]
).$milisec));return ($Timeline);}sub 
Common::NXTime::getLoggerTimelineOnlyMicroseconds{package Common::NXTime;no 
warnings;(my ($milisec,@time)=__getTimeMs ());($milisec=((substr ($milisec,
(0x1de9+ 1886-0x2547),(0x074a+ 3215-0x13d6))."\x2e").substr ($milisec,
(0x0653+ 2967-0x11e7))));(my $Timeline=sprintf ($milisec));return ($Timeline);}
sub Common::NXTime::convertLocalTimeFromTimestampToHumanReadableString{package 
Common::NXTime;no warnings;(my $timestamp=shift (@_));(my (@time)=
getLocalTimeFromTimestamp ($timestamp));(my $timeString=sprintf (
"\x25\x30\x34\x64\x2d\x25\x30\x32\x64\x2d\x25\x30\x32\x64\x20\x25\x30\x32\x64\x3a\x25\x30\x32\x64\x3a\x25\x30\x32\x64"
,((0x1314+ 6131-0x239b)+$time[(0x11c0+ 1343-0x16fa)]),($time[
(0x0e0a+ 3464-0x1b8e)]+(0x0734+ 2287-0x1022)),$time[(0x0824+ 2859-0x134c)],$time
[(0x1152+ 3672-0x1fa8)],$time[(0x008c+ 2077-0x08a8)],$time[(0x03da+ 5905-0x1aeb)
]));return ($timeString);}sub Common::NXTime::getDateTimeForFileName{package 
Common::NXTime;no warnings;(my $dateTime=getLoggerTimeline ());($dateTime=~ s/ [^ ]*$// )
;($dateTime=~ s/-/./gm );($dateTime=~ s/:/./gm );($dateTime=~ s/ /-/gm );return 
($dateTime);}sub Common::NXTime::getSecondsInWeek{package Common::NXTime;no 
warnings;return (604800);}sub Common::NXTime::convertSecondsToDaysRounded{
package Common::NXTime;no warnings;(my $seconds=shift (@_));(my $days=($seconds/
86400));($days=(int ($days)+(0x075b+ 7405-0x2447)));return ($days);}package 
Common::NXTime;no warnings;"\x3f\x3f\x3f";
